.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.graph.entities.bibliographic.pointer\_list module
----------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.pointer_list
   :members:
   :undoc-members:
   :show-inheritance:
